From 793131e1a75821531f0aff61e0ef244229cb64b5 Mon Sep 17 00:00:00 2001
From: Kyotaro Horiguchi <horikyota.ntt@gmail.com>
Date: Mon, 7 Apr 2025 15:48:43 +0900
Subject: [PATCH] Make prep_status() message translatable

Avoid string literal concatenation involving XLOG_CONTROL_FILE, which
was introduced by commit 73c97812ff and made the message
untranslatable. Use %s instead, and quote the file name for
consistency with similar messages.
---
 src/bin/pg_upgrade/controldata.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/src/bin/pg_upgrade/controldata.c b/src/bin/pg_upgrade/controldata.c
index 8b7c349a875..21bf719f697 100644
--- a/src/bin/pg_upgrade/controldata.c
+++ b/src/bin/pg_upgrade/controldata.c
@@ -758,7 +758,8 @@ disable_old_cluster(transferMode transfer_mode)
 				new_path[MAXPGPATH];
 
 	/* rename pg_control so old server cannot be accidentally started */
-	prep_status("Adding \".old\" suffix to old " XLOG_CONTROL_FILE);
+	/* translator: %s is the file path of the control file. */
+	prep_status("Adding \".old\" suffix to old \"%s\"", XLOG_CONTROL_FILE);
 
 	snprintf(old_path, sizeof(old_path), "%s/%s", old_cluster.pgdata, XLOG_CONTROL_FILE);
 	snprintf(new_path, sizeof(new_path), "%s/%s.old", old_cluster.pgdata, XLOG_CONTROL_FILE);
-- 
2.43.5

